yakumo.mapper.Resource

Package yakumo :: Module mapper :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

    object --+
             |
            Resource

Instance Methods | [hide private]
__init__(self, manager_path) x.__init__(...) initializes x; see help(type(x)) for signature | source code
_load_manager_class(self, manager_class) | source code
to_attr(self, manager_class, id, do_raise=False) | source code
to_json(self, manager_class, obj) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| manager_class = `None`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, manager_path) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)